Available templates — Projy 0.1 documentation

### Navigation

- index
- next |
- previous |
- Projy 0.1 documentation »

# Available templates

Here is a list of all the templates, but also collectors, integrated into Projy at the moment. Of course, anyone can propose new templates, they’ll be integrated into Projy.

## Project templates

Project templates are used to create a files/directories structure. That’s the second argument of the command line. For this list, the projects we create are all called `TowelStuff`. They are ordered by the programming language they use.

### LaTeX

These are LaTeX templates.

#### LaTeX book

The command:

    $ projy LaTeXBook TowelStuff

produces:

    TowelStuff/
        TowelStuff.tex          - LaTeXBookFileTemplate
        references.bib          - BibTeXFileTemplate
        Makefile                - LaTeXMakefileFileTemplate

Note: the `Makefile` uses Latexmk.

### Python

These are Python templates.

#### Python package

The command:

    $ projy PythonPackage TowelStuff

produces:

    TowelStuff/
        bootstrap               - BootstrapScriptFileTemplate
        CHANGES.txt             - PythonPackageCHANGESFileTemplate
        LICENSE.txt             - GPL3FileTemplate
        MANIFEST.in             - PythonPackageMANIFESTFileTemplate
        README.txt              - READMEReSTFileTemplate
        setup.py                - PythonPackageSetupFileTemplate

    TowelStuff/docs/
        index.rst

    TowelStuff/towelstuff/
        __init__.py

#### Python script

The command:

    $ projy PythonScript TowelStuff

produces:

    TowelStuff/
        TowelStuff.py           - PythonScriptFileTemplate

### Projy itself!

Finally, a bit of a special template, which lets you create a Projy template and an empty file template from Projy itself. Call it meta if you want :-) See Extending Projy to know how such templates are meant to be written.

The command:

    $ projy ProjyTemplate TowelStuff

produces:

    /
        TowelStuffTemplate.py       - ProjyTemplateFileTemplate
        TowelStuffFileTemplate.txt

## File templates

### LaTeX files

- `BibTeXFileTemplate`
- `LaTeXBookFileTemplate`
- `LaTeXMakefileFileTemplate`

### Python files

- `ProjyTemplateFileTemplate`
- `PythonPackageCHANGESFileTemplate`
- `PythonPackageMANIFESTFileTemplate`
- `PythonPackageSetupFileTemplate`
- `PythonScriptFileTemplate`

### Bash files

- `BootstrapScriptFileTemplate`

### Text files

- `READMEReSTFileTemplate`

### Licenses

- `AGPL3FileTemplate`
- `ApacheLicenseFileTemplate`
- `BSDLicenseFileTemplate`
- `DWTFYWTPLFileTemplate`
- `GPL2FileTemplate`
- `GPL3FileTemplate`
- `LaTeX3LicenseFileTemplate`
- `LGPL3FileTemplate`
- `MITLicenseFileTemplate`
- `MPL2FileTemplate`
- `PythonLicense2FileTemplate`

## Collectors

Here is the list of currently available collectors:

- `AuthorCollector`
- `AuthorMailCollector`

### Navigation

- index
- next |
- previous |
- Projy 0.1 documentation »